<template>
    <div>
        <el-dialog
            :title="title"
            :visible="visible"
            :before-close="handleClose"
            :close-on-click-modal="false"
            width="60%"
            top="5vh"
        >
            <el-descriptions title="基础信息" border :column="3">
                <!-- direction="vertical" -->
                <el-descriptions-item label="具体举措" :span="3">{{
                    parameter.reformSpecificMeasures
                }}</el-descriptions-item>
                <el-descriptions-item label="迭代依据" :span="3"
                    >{{ parameter.iterationAccording }}
                </el-descriptions-item>
                <!-- <el-descriptions-item label="分发类型"
                    >{{ this.getDictName('fflx', parameter.distributionType) }}
                </el-descriptions-item> -->
                <el-descriptions-item label="举措类型"
                    >{{ this.getDictName('zrdwddlx', parameter.iteration) }}
                </el-descriptions-item>
                <el-descriptions-item label="审核状态">
                    <template>
                        <status-by-color :status="parameter.status" />
                    </template>
                </el-descriptions-item>
            </el-descriptions>
            <br />
            <el-descriptions title="月度计划"></el-descriptions>
            <el-table
                v-loading="loading"
                :data="pilotSpecificScheduleList"
                size="mini"
                :header-cell-style="{
                    'text-align': 'center',
                }"
            >
                <el-table-column
                    type="index"
                    label="序号"
                    align="center"
                ></el-table-column>
                <el-table-column
                    prop="planYear"
                    width="100"
                    label="计划年度"
                    align="center"
                >
                </el-table-column>
                <el-table-column
                    prop="planMonth"
                    width="100"
                    label="计划月度"
                    align="center"
                >
                </el-table-column>
                <el-table-column width="140" label="计划类型" align="center">
                    <template v-slot="{row}">
                        {{ getDictName('yd_jhlx', row.planType) }}
                    </template>
                </el-table-column>
                <el-table-column
                    prop="planContent"
                    label="计划内容"
                    align="center"
                >
                    <!-- <template v-slot="{row}">
                        <el-input
                            :disabled="disabled"
                            v-model.trim="row.planContent"
                            type="textarea"
                        />
                    </template> -->
                </el-table-column>
            </el-table>
            <span slot="footer" class="dialog-footer">
                <el-button @click="handleClose">关闭</el-button>
            </span>
        </el-dialog>
    </div>
</template>

<script>
import org from '@/api/org.js'
import utils from '@/utils.js'
import {TableMixin} from '@/mixins/tableMixin'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import measureIterationApplication from '@/api/projectActionIteration/measureIterationApplication.js'
export default {
    name: 'ApplyForDialog',
    mixins: [TableMixin],
    data() {
        return {
            loading: false,
            visible: false,
            title: '详情',
            parameter: {},
            pilotSpecificScheduleList: [],
        }
    },
    created() {},
    mounted() {},
    methods: {
        edit(val) {
            this.loading = true
            this.visible = true
            this.parameter = val
            let data = {
                pageBean: {
                    page: 1,
                    pageSize: -1,
                },
                querys: [
                    {
                        group: 'main',
                        operation: 'EQUAL',
                        parentGroup: '',
                        property: 'MEASURES_ID_',
                        relation: 'AND',
                        value: val.id,
                    },
                ],
            }
            measureIterationApplication.getMonthDetails(data, (res) => {
                if (res.rows.length) {
                    res.rows.forEach((item) => {
                        item.planYear = item.planYear.toString()
                        item.planMonth = item.planMonth.toString()
                    })
                    this.pilotSpecificScheduleList = res.rows
                }
                this.loading = false
            })
        },

        getDictName(code, value) {
            return utils.getDictName(code, value)
        },

        // 关闭新增人员窗口
        handleClose() {
            this.visible = false
            this.parameter = {}
            this.pilotSpecificScheduleList = []
        },
    },
}
</script>

<style lang="scss" scoped>
	@import "~@/assets/css/element-variables.scss";

	.add-btn {
		font-weight: bold;
		cursor: pointer;
		color: $--color-primary;
	}

	.del-btn {
		font-weight: bold;
		margin-left: 10px;
		color: $--color-danger;
		cursor: pointer;
	}

	/deep/.el-dialog__body {
		max-height: 600px;
		overflow-y: auto;

	}
</style>
